Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3243)

Unified Diff: ios/web/public/web_state/navigation_context.h

Issue 2734293002: s/IsSamePage/IsSameDocument for NavigationContext. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web/public/test/fakes/test_web_state_observer.mm ('k') | ios/web/public/web_state/web_state_observer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web/public/web_state/navigation_context.h
diff --git a/ios/web/public/web_state/navigation_context.h b/ios/web/public/web_state/navigation_context.h
index 44b48eb220c1fbfbf45d7ac15d07c50a041005fa..d6c9c42c1ce9783a7670b9eae95726e02d4faa54 100644
--- a/ios/web/public/web_state/navigation_context.h
+++ b/ios/web/public/web_state/navigation_context.h
@@ -24,12 +24,12 @@ class NavigationContext {
// The URL the WebState is navigating to.
virtual const GURL& GetUrl() const = 0;
// Whether the navigation happened in the same page. Examples of same page
// navigations are:
// * reference fragment navigations
// * pushState/replaceState
- // * same page history navigation
- virtual bool IsSamePage() const = 0;
+ // * same document history navigation
+ virtual bool IsSameDocument() const = 0;
// Whether the navigation resulted in an error page.
virtual bool IsErrorPage() const = 0;
« no previous file with comments | « ios/web/public/test/fakes/test_web_state_observer.mm ('k') | ios/web/public/web_state/web_state_observer.h » ('j') | no next file with comments »
@@ -24,12 +24,12 @@ class NavigationContext {
// The URL the WebState is navigating to.
virtual const GURL& GetUrl() const = 0;
- // Whether the navigation happened in the same page. Examples of same page
- // navigations are:
+ // Whether the navigation happened within the same document. Examples of same
+ // document navigations are:
// * reference fragment navigations
// * pushState/replaceState

Powered by Google App Engine
This is Rietveld 408576698